@@ -1,4 +1,4 @@
-__version__ = '1.0.21'
+__version__ = '1.0.22'
 __author__ = 'arnold'
 
 import json
@@ -118,4 +118,4 @@ class TerraformQueryExtension(Extension):
                 if(value_name is not None):
                     return output["attributes"]["value"][value_name]
                 else:
-                    sys.exit("Value is None") 
+                    sys.exit("Value is None for attribute " +name) 
